@@ -3,43 +3,6 @@
 #'
 #' Fit an oblique random survival forest
 #'
-#' @srrstats {G1.4} *documented with Roxygen*
-#' @srrstats {G1.1} *aorsf is an improvement of the ORSF algorithm implemented in obliqueRSF, which was an extension of Hemant Ishwaran's random survival forest.*
-#' @srrstats {G1.3} *linear combinations of inputs defined.*
-#' @srrstats {G1.5} *orsf() will be used in publications to benchmark performance of the aorsf package in computation speed and prediction accuracy.*
-#' @srrstats {G1.6} *orsf() should be used to compare performance claims with other packages.*
-#' @srrstats {G2.1} *Inputs have indication of type in parentheticals. This format is used in all exported functions.*
-#' @srrstats {G5.2a} *messages produced here (e.g., with `stop()`, `warning()`, `message()`) are unique and make effort to highlight the specific data elements that cause the error*
-#' @srrstats {G2.0a} *secondary documentation of arg lengths. When an input has length 1, a parenthetical gives the specific type of value it should be and uses a singular description (e.g., an integer). When inputs have length > 1, a vector description is used (e.g., integer vector)*
-#' @srrstats {ML1.0} *Documentation includes a subsection that makes clear conceptual distinction between train and test data*
-#' @srrstats {ML3.3} *Properties and behaviours of aorsf models are explicitly compared with objects produced by other ML software in the "Introduction to aorsf" vignette.*
-#' @srrstats {ML4.0} *orsf() is a unified single-function interface to model training. orsf_train() is able to receive as input an untrained model specified by orsf() when no_fit = TRUE. Models with categorically different specifications are able to be submitted to the same model training function.*
-#' @srrstats {ML5.2, ML5.2a} *The structure and functionality of trained aorsf objects is documented through vignettes. In particular, basic functionality extending from the aorsf class is explicitly described in the "Introduction to aorsf" vignette, and additional functionality is documented in the "Out-of-bag predictions and evaluation" and "Compute partial dependence with ORSF" vignettes. Each vignettes demonstrates functionality clearly with example code.*
-#' @srrstats {ML5.3} *Assessment of model performance is implemented through out-of-bag error, which is finalized after a model is trained*
-#' @srrstats {ML5.4} *The "Out-of-bag predictions and evaluation" vignette shows how to implement built-in or user-specified functions for this functionality.*
-#' @srrstats {ML1.1} *Training data are labelled as "train".*
-#' @srrstats {G2.5} *factors used as predictors can be ordered and un-ordered.*
-#' @srrstats {ML4.1b} *The value of out-of-bag error can be returned for every oobag_eval_every step.*
-#' @srrstats {ML4.2} *The extraction of out-of-bag error is explicitly documented with example code in the "Out-of-bag predictions and evaluation" vignette.*
-#' @srrstats {ML3.5b} *Users can specify the kind of loss function to assess distance between model estimates and desired output. This is discussed in detail in the "Out-of-bag predictions and evaluation" vignette.*
-#' @srrstats {ML5.4a} *Harrell's C-statistic, an internally utilized metric for model performance, is clearly and distinctly documented and cited.*
-#' @srrstats {ML5.4b} *It is possible to submit custom metrics to a model assessment function, and the ability to do so is clearly documented. The "Out-of-bag predictions and evaluation" vignette provides example code.*
-#' @srrstats {ML2.0, ML2.0b} *orsf() enables pre-processing steps to be defined and parametrized without fitting a model when no_fit is TRUE, returning an object with a defined class minimally intended to implement a default `print` method which summarizes the model specifications.*
-#' @srrstats {ML3.0} *Model specification can be implemented prior to actual model fitting or training*
-#' @srrstats {ML3.0a} *As pre-processing, model specification, and training are controlled by the orsf() function, an input parameter (no_fit) enables models to be specified yet not fitted.*
-#' @srrstats {ML3.0c} *when no_fit=TRUE, orsf() will return an object that can be directly trained using orsf_train().*
-#' @srrstats {ML1.6a} *Explain why missing values are not admitted.*
-#' @srrstats {G1.0} *Jaeger et al describes the ORSF algorithm that aorsf is based on. Note: aorsf uses a different approach to create linear combinations of inputs for speed reasons, but orsf_control_net() allows users to make ensembles that are very similar to obliqueRSF::ORSF().*
-#' @srrstats {ML1.6b} *Explicit example showing how missing values may be imputed rather than discarded.*
-#' @srrstats {ML6.0} *Reference section explicitly links to aorsf-bench, which includes training and testing stages, and which clearly indicates a need for distinct training and test data sets.*
-#' @srrstats {ML6.1} *clearly document how aorsf can be embedded within a typical full ML workflow.*
-#' @srrstats {ML6.1a} *Embed aorsf within a full workflow using tidymodels and tidyverse*
-#' @srrstats {ML5.2b} *Documentation includes examples of how to save and re-load trained model objects for their re-use.*
-#' @srrstats {ML2.3} *Values associated with transformations are recorded in the object returned by orsf()*
-#' @srrstats {ML1.3} *Input data are partitioned as training (in-bag) and test (out-of-bag) data within orsf_fit().*
-#' @srrstats {ML4.1} *orsf_fit() retains information on model-internal parameters.*
-#' @srrstats {ML4.1a} *orsf_fit() output includes all model-internal parameters, specifically the linear combination coefficients.*
-#'
 #' @param data a `r roxy_data_allowed()` that contains the
 #'  relevant variables.
 #'
@@ -85,16 +48,35 @@
 #'  of randomly selected predictors, up to `n_retry` times. Default is
 #'  `n_retry = 3`. Set `n_retry = 0` to prevent any retries.
 #'
+#' @param n_thread `r roxy_n_thread_header("growing trees, computing predictions, and computing importance")`
+#'
 #' @param mtry (_integer_) Number of predictors randomly included as candidates
 #'   for splitting a node. The default is the smallest integer greater than
 #'   the square root of the number of total predictors, i.e.,
 #'   `mtry = ceiling(sqrt(number of predictors))`
 #'
+#' @param sample_with_replacement (_logical_) If `TRUE` (the default),
+#'   observations are sampled with replacement when an in-bag sample
+#'   is created for a decision tree. If `FALSE`, observations are
+#'   sampled without replacement and each tree will have an in-bag sample
+#'   containing `sample_fraction`% of the original sample.
+#'
+#' @param sample_fraction (_double_) the proportion of observations that
+#'   each trees' in-bag sample will contain, relative to the number of
+#'   rows in `data`. Only used if `sample_with_replacement` is `FALSE`.
+#'   Default value is 0.632.
+#'
 #' @param leaf_min_events (_integer_) minimum number of events in a
 #'   leaf node. Default is `leaf_min_events = 1`
 #'
 #' @param leaf_min_obs (_integer_) minimum number of observations in a
-#'   leaf node. Default is `leaf_min_obs = 5`
+#'   leaf node. Default is `leaf_min_obs = 5`.
+#'
+#' @param split_rule (_character_) how to assess the quality of a potential
+#'   splitting rule for a node. Valid options are
+#'
+#'   - 'logrank' : a log-rank test statistic.
+#'   - 'cstat'   : Harrell's concordance statistic.
 #'
 #' @param split_min_events (_integer_) minimum number of events required
 #'   in a node to consider splitting it. Default is `split_min_events = 5`
@@ -103,19 +85,21 @@
 #'   in a node to consider splitting it. Default is `split_min_obs = 10`.
 #'
 #' @param split_min_stat (double) minimum test statistic required to split
-#'   a node. Default is 3.841459 for the log-rank test, which is roughly
-#'   a p-value of 0.05
+#'   a node. Default is 3.841459 if `split_rule = 'logrank'` and 0.50 if
+#'   `split_rule = 'cstat'`. If no splits are found with a statistic
+#'   exceeding `split_min_stat`, the given node either becomes a leaf or
+#'   a retry occurs (up to `n_retry` retries).
 #'
 #' @param oobag_pred_type (_character_) The type of out-of-bag predictions
 #'   to compute while fitting the ensemble. Valid options are
 #'
 #'   - 'none' : don't compute out-of-bag predictions
-#'   - 'risk' : predict the probability of having an event at or before `oobag_pred_horizon`.
+#'   - 'risk' : probability of event occurring at or before `oobag_pred_horizon`.
 #'   - 'surv' : 1 - risk.
-#'   - 'chf'  : predict cumulative hazard function
-#'
-#' Mortality ('mort')is not implemented for out of bag predictions yet, but it
-#'   will be in a future update.
+#'   - 'chf'  : cumulative hazard function at `oobag_pred_horizon`.
+#'   - 'mort' : mortality, i.e., the number of events expected if all
+#'              observations in the training data were identical to a
+#'              given observation.
 #'
 #' @param oobag_pred_horizon (_numeric_) A numeric value indicating what time
 #'   should be used for out-of-bag predictions. Default is the median
@@ -172,15 +156,13 @@
 #'     to the output will be the imputed version of `data`.
 #'
 #' @param verbose_progress (_logical_) if `TRUE`, progress messages are
-#'   printed in the console.
+#'   printed in the console. If `FALSE` (the default), nothing is printed.
 #'
 #' @param ... `r roxy_dots()`
 #'
 #' @param object an untrained 'aorsf' object, created by setting
 #'   `no_fit = TRUE` in `orsf()`.
 #'
-#' @srrstats {ML5.0} *The result of applying orsf training processes results in a single model object.*
-#'
 #' @return an accelerated oblique RSF object (`aorsf`)
 #'
 #' @details
@@ -239,6 +221,13 @@
 #'  importance or permutation importance, but it will not have any role
 #'  for ANOVA importance.
 #'
+#' **n_thread**:
+#'
+#' If an R function must be called from C++ (i.e., user-supplied function to
+#'  compute out-of-bag error or identify linear combinations of variables),
+#'  `n_thread` will automatically be set to 1 because attempting to run R
+#'  functions in multiple threads will cause the R session to crash.
+#'
 #' @section What is an oblique decision tree?:
 #'
 #' Decision trees are developed by splitting a set of training data into two
@@ -297,7 +286,7 @@
 #'
 #' `r roxy_cite_jaeger_2019()`
 #'
-#' `r roxy_cite_jaeger_2022()`
+#' `r roxy_cite_jaeger_2023()`
 #'
 #' @export
 #'
@@ -312,12 +301,18 @@ orsf <- function(data,
                  n_tree = 500,
                  n_split = 5,
                  n_retry = 3,
+                 n_thread = 1,
                  mtry = NULL,
+                 sample_with_replacement = TRUE,
+                 sample_fraction = 0.632,
                  leaf_min_events = 1,
                  leaf_min_obs = 5,
+                 split_rule = 'logrank',
                  split_min_events = 5,
                  split_min_obs = 10,
-                 split_min_stat = 3.841459,
+                 split_min_stat = switch(split_rule,
+                                         "logrank" = 3.841459,
+                                         "cstat" = 0.50),
                  oobag_pred_type = 'surv',
                  oobag_pred_horizon = NULL,
                  oobag_eval_every = n_tree,
@@ -331,8 +326,6 @@ orsf <- function(data,
                  verbose_progress = FALSE,
                  ...){
 
- #' @srrstats {G2.8} *As part of initial pre-processing, run checks on inputs to ensure that all other sub-functions receive inputs of a single defined class or type.*
-
  check_dots(list(...), .f = orsf)
 
  if(!is.data.frame(data))
@@ -346,9 +339,13 @@ orsf <- function(data,
   n_tree = n_tree,
   n_split = n_split,
   n_retry = n_retry,
+  n_thread = n_thread,
   mtry = mtry,
+  sample_with_replacement = sample_with_replacement,
+  sample_fraction = sample_fraction,
   leaf_min_events = leaf_min_events,
   leaf_min_obs = leaf_min_obs,
+  split_rule = split_rule,
   split_min_events = split_min_events,
   split_min_obs = split_min_obs,
   split_min_stat = split_min_stat,
@@ -357,81 +354,48 @@ orsf <- function(data,
   oobag_eval_every = oobag_eval_every,
   importance = importance,
   tree_seeds = tree_seeds,
-  attach_data = attach_data
+  attach_data = attach_data,
+  verbose_progress = verbose_progress
  )
 
+ #TODO: more polish
+ if(split_rule == "cstat" && split_min_stat >= 1){
+  stop("If split_rule is 'cstat', split_min_stat must be < 1",
+       call. = FALSE)
+ }
+
  oobag_pred <- oobag_pred_type != 'none'
 
- orsf_type <- attr(control, 'type')
+ if(sample_fraction == 1 && oobag_pred){
+  stop(
+   "cannot compute out-of-bag predictions if no samples are out-of-bag.",
+   " Try setting sample_fraction < 1 or oobag_pred_type = 'none'.",
+   call. = FALSE
+  )
+ }
 
- switch(
-  orsf_type,
-
-  'fast' = {
-
-   control_net <- orsf_control_net()
-   control_cph <- control
-   f_beta      <- function(x) x
-
-  },
-
-  'cph' = {
-
-   control_net <- orsf_control_net()
-   control_cph <- control
-   f_beta      <- function(x) x
-
-  },
-
-  'net' = {
-
-   if (!requireNamespace("glmnet", quietly = TRUE)) {
-    stop(
-     "Package \"glmnet\" must be installed to use",
-     " orsf_control_net() with orsf().",
-     call. = FALSE
-    )
-   }
-
-   control_net <- control
-   control_cph <- orsf_control_fast(do_scale = FALSE)
-   f_beta      <- penalized_cph
-  },
-
-  "custom" = {
-
-   control_net <- orsf_control_net()
-   control_cph <- orsf_control_fast(do_scale = FALSE)
-   f_beta      <- control$beta_fun
-
-  }
-
- )
 
  if(is.null(oobag_fun)){
 
   f_oobag_eval <- function(x) x
-  type_oobag_eval <- 'H'
+  type_oobag_eval <- if(oobag_pred) 'cstat' else 'none'
 
  } else {
 
   check_oobag_fun(oobag_fun)
   f_oobag_eval <- oobag_fun
-  type_oobag_eval <- 'U'
+  type_oobag_eval <- 'user'
+
+  if(oobag_pred_type == 'leaf'){
+   warning("a user-supplied oobag function cannot be",
+           "applied when oobag_pred_type = 'leaf'",
+           call. = FALSE)
+  }
 
  }
 
- cph_method <- control_cph$cph_method
- cph_eps <- control_cph$cph_eps
- cph_iter_max <- control_cph$cph_iter_max
- cph_do_scale <- control_cph$cph_do_scale
- net_alpha <- control_net$net_alpha
- net_df_target <- control_net$net_df_target
-
- if(importance %in% c("permute", "negate") && !oobag_pred){
-  oobag_pred <- TRUE # Should I add a warning?
-  oobag_pred_type <- 'surv'
- }
+ # can't evaluate the oobag predictions if they aren't aggregated
+ if(oobag_pred_type == 'leaf') type_oobag_eval <- 'none'
 
 
  formula_terms <- suppressWarnings(stats::terms(formula, data=data))
@@ -441,20 +405,36 @@ orsf <- function(data,
 
  names_y_data <- all.vars(formula[[2]])
 
- if(length(names_y_data) == 1){
-  # this is fine if the response is a Surv object,
-  if(!inherits(data[[names_y_data]], 'Surv')){
-   # otherwise it will be a problem
-   stop("formula must have two variables (time & status) as the response",
-        call. = FALSE)
+ outcome_type <- infer_outcome_type(names_y_data, data)
+
+ if(outcome_type %in% c('regression', 'classification')) stop("not ready yet")
+
+ if(control$tree_type == 'unknown'){
+
+  if(outcome_type == 'unknown'){
+   stop("could not determine outcome type", call. = FALSE)
+  }
+
+  control$tree_type <- outcome_type
+
+ }
+
+ if(control$lincomb_type == 'net'){
+
+  if (!requireNamespace("glmnet", quietly = TRUE)) {
+   stop(
+    "Package \"glmnet\" must be installed to use",
+    " orsf_control_net() with orsf().",
+    call. = FALSE
+   )
   }
 
  }
 
- if(length(names_y_data) > 2){
-  stop("formula must have two variables (time & status) as the response",
-       call. = FALSE)
- }
+ tree_type_R = switch(outcome_type,
+                      'classification' = 1,
+                      'regression'= 2,
+                      'survival' = 3)
 
  types_y_data <- vector(mode = 'character',
                         length = length(names_y_data))
@@ -479,10 +459,6 @@ orsf <- function(data,
   stop(msg, call. = FALSE)
  }
 
- #' @srrstats {G2.7} *aorsf accepts as input numeric and categorical predictor variables, including those with unit class. I do not think it is necessary to incorporate any other type of input, since it is relatively straightforward to convert data into a numeric or categorical format.*
-
- #' @srrstats {G2.11} *I cannot write code for every possible vector class to ensure that the vector data will be safely coerced into a a valid class and the attributes will be stored in the orsf_out object. It is much easier and safer for the user to convert a few columns to numeric or factor than it is for me to attempt writing code that will safely coerce every type of vector. That being said, I do find units columns to be helpful and I've written some code to make them an allowable class in input data.*
-
  types_x_data <- check_var_types(data,
                                  names_x_data,
                                  valid_types = c('numeric',
@@ -491,14 +467,6 @@ orsf <- function(data,
                                                  'factor',
                                                  'ordered'))
 
- #' @srrstats {G2.6} *ensure that one-dimensional inputs are appropriately pre-processed. aorsf does not deal with missing data as many other R packages are very good at dealing with it.*
-
- #' @srrstats {G2.13} *check for missing data as part of initial pre-processing prior to passing data to analytic algorithms.*
-
- #' @srrstats {G2.15} *Never pass data with potential missing values to any base routines.*
-
- #' @srrstats {G2.16} *Throw hard errors if undefined values are detected.*
-
  for(i in c(names_y_data, names_x_data)){
 
   if(any(is.infinite(data[[i]]))){
@@ -588,6 +556,8 @@ orsf <- function(data,
 
    'omit' = {
     data <- collapse::na_omit(data, cols = names_x_data)
+    # cc <- stats::complete.cases(data[, names_x_data])
+    # data <- data[cc, ]
    },
 
    'impute_meanmode' = {
@@ -607,14 +577,6 @@ orsf <- function(data,
 
  if(is.null(mtry)) mtry <- ceiling(sqrt(ncol(x)))
 
- if(is.null(net_df_target)) net_df_target <- mtry
-
- # warn instead?
- if(net_df_target > mtry)
-  stop("net_df_target = ", net_df_target,
-       " must be <= mtry, which is ", mtry,
-       call. = FALSE)
-
  n_events <- collapse::fsum(y[, 2])
 
  # some additional checks that are dependent on the outcome variable
@@ -626,6 +588,22 @@ orsf <- function(data,
   append_to_msg = "(number of columns in the one-hot encoded x-matrix)"
  )
 
+ if(is.null(control$lincomb_df_target)){
+
+  control$lincomb_df_target <- mtry
+
+ } else {
+
+  check_arg_lteq(
+   arg_value = control$lincomb_df_target,
+   arg_name = 'df_target',
+   bound = mtry,
+   append_to_msg = "(number of randomly selected predictors)"
+  )
+
+ }
+
+
  check_arg_lteq(
   arg_value = leaf_min_events,
   arg_name = 'leaf_min_events',
@@ -652,82 +630,108 @@ orsf <- function(data,
 
  if(!is.null(oobag_pred_horizon)){
 
-  if(oobag_pred_horizon <= 0)
+  if(any(oobag_pred_horizon <= 0))
 
    stop("Out of bag prediction horizon (oobag_pred_horizon) must be > 0",
         call. = FALSE)
 
  } else {
 
-  # tell orsf.cpp to make its own oobag_pred_horizon by setting this to 0
-  oobag_pred_horizon <- 0
+  # use training data to provide sensible default
+  oobag_pred_horizon <- stats::median(y[, 1])
 
  }
 
  sorted <-
-  collapse::radixorder(y[, 1],  # order this way for risk sets
-                       -y[, 2]) # order this way for oob C-statistic.
+  collapse::radixorder(y[, 1],  # order for risk sets
+                       -y[, 2]) # order for oob C-statistic.
+
+ if(is.null(weights)) weights <- rep(1, nrow(x))
 
  x_sort <- x[sorted, , drop = FALSE]
  y_sort <- y[sorted, , drop = FALSE]
+ w_sort <- weights[sorted]
 
- if(is.null(weights)) weights <- double()
- if(is.null(tree_seeds)) tree_seeds <- vector(mode = 'integer', length = 0L)
+ if(length(tree_seeds) == 1 && n_tree > 1){
+  set.seed(tree_seeds)
+  tree_seeds <- sample(x = n_tree*10, size = n_tree, replace = FALSE)
+ } else if(is.null(tree_seeds)){
+  tree_seeds <- sample(x = n_tree*10, size = n_tree, replace = FALSE)
+ }
 
- orsf_out <- orsf_fit(
-  x                 = x_sort,
-  y                 = y_sort,
-  weights           = if(length(weights) > 0) weights[sorted] else weights,
-  n_tree            = if(no_fit) 0 else n_tree,
-  n_split_          = n_split,
-  mtry_             = mtry,
-  leaf_min_events_  = leaf_min_events,
-  leaf_min_obs_     = leaf_min_obs,
-  split_min_events_ = split_min_events,
-  split_min_obs_    = split_min_obs,
-  split_min_stat_   = split_min_stat,
-  cph_method_       = switch(tolower(cph_method),
-                             'breslow' = 0,
-                             'efron'   = 1),
-  cph_eps_            = cph_eps,
-  cph_iter_max_       = cph_iter_max,
-  cph_do_scale_       = cph_do_scale,
-  net_alpha_          = net_alpha,
-  net_df_target_      = net_df_target,
-  oobag_pred_         = oobag_pred,
-  oobag_pred_type_    = switch(oobag_pred_type,
-                               "none" = "N",
-                               "surv" = "S",
-                               "risk" = "R",
-                               "chf"  = "H"),
-  oobag_pred_horizon_ = oobag_pred_horizon,
-  oobag_eval_every_   = oobag_eval_every,
-  oobag_importance_   = importance %in% c("negate", "permute"),
-  oobag_importance_type_ = switch(importance,
-                                  "none" = "O",
-                                  "anova" = "A",
-                                  "negate" = "N",
-                                  "permute" = "P"),
-  #' @srrstats {G2.4a} *converting to integer in case R does that thing where it assumes the integer values you gave it are supposed to be doubles*
-  tree_seeds        = as.integer(tree_seeds),
-  max_retry_        = n_retry,
-  f_beta            = f_beta,
-  type_beta_        = switch(orsf_type,
-                             'fast' = 'C',
-                             'cph' = 'C',
-                             'net' = 'N',
-                             'custom' = 'U'),
-  f_oobag_eval      = f_oobag_eval,
-  type_oobag_eval_  = type_oobag_eval,
-  verbose_progress  = verbose_progress
- )
+ vi_max_pvalue = 0.01
+
+ orsf_out <- orsf_cpp(x = x_sort,
+                      y = y_sort,
+                      w = w_sort,
+                      tree_type_R = tree_type_R,
+                      tree_seeds = as.integer(tree_seeds),
+                      loaded_forest = list(),
+                      n_tree = n_tree,
+                      mtry = mtry,
+                      sample_with_replacement = sample_with_replacement,
+                      sample_fraction = sample_fraction,
+                      vi_type_R = switch(importance,
+                                         "none" = 0,
+                                         "negate" = 1,
+                                         "permute" = 2,
+                                         "anova" = 3),
+                      vi_max_pvalue = vi_max_pvalue,
+                      leaf_min_events = leaf_min_events,
+                      leaf_min_obs = leaf_min_obs,
+                      split_rule_R = switch(split_rule,
+                                            "logrank" = 1,
+                                            "cstat" = 2),
+                      split_min_events = split_min_events,
+                      split_min_obs = split_min_obs,
+                      split_min_stat = split_min_stat,
+                      split_max_cuts = n_split,
+                      split_max_retry = n_retry,
+                      lincomb_R_function = control$lincomb_R_function,
+                      lincomb_type_R = switch(control$lincomb_type,
+                                              'glm' = 1,
+                                              'random' = 2,
+                                              'net' = 3,
+                                              'custom' = 4),
+                      lincomb_eps = control$lincomb_eps,
+                      lincomb_iter_max = control$lincomb_iter_max,
+                      lincomb_scale = control$lincomb_scale,
+                      lincomb_alpha = control$lincomb_alpha,
+                      lincomb_df_target = control$lincomb_df_target,
+                      lincomb_ties_method = switch(tolower(control$lincomb_ties_method),
+                                                   'breslow' = 0,
+                                                   'efron'   = 1),
+                      pred_type_R = switch(oobag_pred_type,
+                                           "none" = 0,
+                                           "risk" = 1,
+                                           "surv" = 2,
+                                           "chf"  = 3,
+                                           "mort" = 4,
+                                           "leaf" = 8),
+                      pred_mode = FALSE,
+                      pred_aggregate = oobag_pred_type != 'leaf',
+                      pred_horizon = oobag_pred_horizon,
+                      oobag = oobag_pred,
+                      oobag_R_function = f_oobag_eval,
+                      oobag_eval_type_R = switch(type_oobag_eval,
+                                                 'none' = 0,
+                                                 'cstat' = 1,
+                                                 'user' = 2),
+                      oobag_eval_every = oobag_eval_every,
+                      pd_type_R = 0,
+                      pd_x_vals = list(matrix(0, ncol=1, nrow=1)),
+                      pd_x_cols = list(matrix(1L, ncol=1, nrow=1)),
+                      pd_probs = c(0),
+                      n_thread = n_thread,
+                      write_forest = TRUE,
+                      run_forest = !no_fit,
+                      verbosity = as.integer(verbose_progress))
 
  # if someone says no_fit and also says don't attach the data,
  # give them a warning but also do the right thing for them.
  orsf_out$data <- if(attach_data) data else NULL
 
-
- if(importance != 'none'){
+ if(importance != 'none' && !no_fit){
   rownames(orsf_out$importance) <- colnames(x)
   orsf_out$importance <-
    rev(orsf_out$importance[order(orsf_out$importance), , drop=TRUE])
@@ -735,40 +739,46 @@ orsf <- function(data,
 
  if(oobag_pred){
 
+  # makes labels for oobag evaluation type
+  orsf_out$eval_oobag$stat_type <-
+   switch(EXPR = as.character(orsf_out$eval_oobag$stat_type),
+          "0" = "None",
+          "1" = "Harrell's C-statistic",
+          "2" = "User-specified function")
+
+  if(!no_fit){
 
   # put the oob predictions into the same order as the training data.
   unsorted <- collapse::radixorder(sorted)
 
-  # clear labels for oobag evaluation type
+  if(oobag_pred_type == 'leaf'){
+   all_rows <- seq(nrow(data))
+   for(i in seq(n_tree)){
+    rows_inbag <- setdiff(all_rows, orsf_out$forest$rows_oobag[[i]]+1)
+    orsf_out$pred_oobag[rows_inbag, i] <- NA
+   }
+  }
 
-  orsf_out$eval_oobag$stat_type <-
-   switch(EXPR = orsf_out$eval_oobag$stat_type,
-          'H' = "Harrell's C-statistic",
-          'U' = "User-specified function")
-
-  #' @srrstats {G2.10} *drop = FALSE for type consistency*
   orsf_out$pred_oobag <- orsf_out$pred_oobag[unsorted, , drop = FALSE]
+  orsf_out$pred_oobag[is.nan(orsf_out$pred_oobag)] <- NA_real_
 
- } else {
+  # mortality predictions should always be 1 column
+  # b/c they do not depend on the prediction horizon
+  if(oobag_pred_type == 'mort'){
+   orsf_out$pred_oobag <-
+    orsf_out$pred_oobag[, 1L, drop = FALSE]
 
-  if(oobag_pred_horizon == 0)
-   # this would get added by orsf_fit if oobag_pred was TRUE
-   orsf_out$pred_horizon <- stats::median(y[, 1])
-  else
-   orsf_out$pred_horizon <- oobag_pred_horizon
+   orsf_out$eval_oobag$stat_values <-
+    orsf_out$eval_oobag$stat_values[, 1, drop = FALSE]
+  }
+
+  }
 
  }
 
- n_leaves_mean <- 0
+ orsf_out$pred_horizon <- oobag_pred_horizon
 
- if(!no_fit) {
-  n_leaves_mean <-
-   collapse::fmean(
-    vapply(orsf_out$forest,
-           function(t) nrow(t$leaf_node_index),
-           FUN.VALUE = integer(1))
-   )
- }
+ n_leaves_mean <- compute_mean_leaves(orsf_out$forest)
 
  attr(orsf_out, 'control')             <- control
  attr(orsf_out, 'mtry')                <- mtry
@@ -791,35 +801,33 @@ orsf <- function(data,
  attr(orsf_out, 'split_min_obs')       <- split_min_obs
  attr(orsf_out, 'split_min_stat')      <- split_min_stat
  attr(orsf_out, 'na_action')           <- na_action
- attr(orsf_out, 'cph_method')          <- cph_method
- attr(orsf_out, 'cph_eps')             <- cph_eps
- attr(orsf_out, 'cph_iter_max')        <- cph_iter_max
- attr(orsf_out, 'cph_do_scale')        <- cph_do_scale
- attr(orsf_out, 'net_alpha')           <- net_alpha
- attr(orsf_out, 'net_df_target')       <- net_df_target
+ attr(orsf_out, 'control')             <- control
  attr(orsf_out, 'numeric_bounds')      <- numeric_bounds
  attr(orsf_out, 'means')               <- means
  attr(orsf_out, 'modes')               <- modes
  attr(orsf_out, 'standard_deviations') <- standard_deviations
  attr(orsf_out, 'trained')             <- !no_fit
  attr(orsf_out, 'n_retry')             <- n_retry
- attr(orsf_out, 'orsf_type')           <- orsf_type
- attr(orsf_out, 'f_beta')              <- f_beta
  attr(orsf_out, 'f_oobag_eval')        <- f_oobag_eval
  attr(orsf_out, 'type_oobag_eval')     <- type_oobag_eval
  attr(orsf_out, 'oobag_pred')          <- oobag_pred
  attr(orsf_out, 'oobag_fun')           <- oobag_fun
  attr(orsf_out, 'oobag_pred_type')     <- oobag_pred_type
  attr(orsf_out, 'oobag_eval_every')    <- oobag_eval_every
+ attr(orsf_out, 'oobag_pred_horizon')  <- oobag_pred_horizon
  attr(orsf_out, 'importance')          <- importance
  attr(orsf_out, 'importance_values')   <- orsf_out$importance
  attr(orsf_out, 'group_factors')       <- group_factors
  attr(orsf_out, 'weights_user')        <- weights
  attr(orsf_out, 'verbose_progress')    <- verbose_progress
+ attr(orsf_out, 'vi_max_pvalue')       <- vi_max_pvalue
+ attr(orsf_out, 'split_rule')          <- split_rule
+ attr(orsf_out, 'n_thread')            <- n_thread
+ attr(orsf_out, 'tree_type')           <- tree_type_R
+ attr(orsf_out, 'tree_seeds')          <- tree_seeds
+ attr(orsf_out, 'sample_with_replacement') <- sample_with_replacement
+ attr(orsf_out, 'sample_fraction')         <- sample_fraction
 
- attr(orsf_out, 'tree_seeds') <- if(is.null(tree_seeds)) c() else tree_seeds
-
- #' @srrstats {ML5.0a} *orsf output has its own class*
  class(orsf_out) <- "orsf_fit"
 
  if(importance != 'none' && !no_fit){
@@ -891,8 +899,6 @@ orsf_data_prep.recipe <- function(data, ...){
 
 }
 
-#' @srrstats {ML2.0a} *objects returned from orsf() with no_fit = TRUE can be directly submitted to orsf_train to train the model specification.*
-#'
 #' @rdname orsf
 #' @export
 orsf_train <- function(object){
@@ -903,8 +909,6 @@ orsf_train <- function(object){
 
 #' Estimate training time
 #'
-#' @srrstats {ML4.5} *include a function to estimate likely time to train a specified model*
-#'
 #' @param object an untrained `aorsf` object
 #'
 #' @param n_tree_subset (_integer_)  how many trees should be fit in order
@@ -1011,75 +1015,96 @@ orsf_train_ <- function(object,
   x <- prep_x_from_orsf(object)
  }
 
- if(is.null(sorted)){
-  sorted <-
-   collapse::radixorder(y[, 1],  # order this way for risk sets
-                        -y[, 2]) # order this way for oob C-statistic.
+ if(is.null(n_tree)){
+  n_tree <- get_n_tree(object)
  }
 
-
- x_sort <- x[sorted, ]
- y_sort <- y[sorted, ]
-
- if(is.null(n_tree)) n_tree <- get_n_tree(object)
-
- oobag_eval_every <- min(n_tree, get_oobag_eval_every(object))
+ if(is.null(sorted)){
+  sorted <- collapse::radixorder(y[, 1], -y[, 2])
+ }
 
  weights <- get_weights_user(object)
 
- orsf_out <- orsf_fit(
-  x                 = x_sort,
-  y                 = y_sort,
-  weights           = if(length(weights) > 0) weights[sorted] else weights,
-  n_tree            = n_tree,
-  n_split_          = get_n_split(object),
-  mtry_             = get_mtry(object),
-  leaf_min_events_  = get_leaf_min_events(object),
-  leaf_min_obs_     = get_leaf_min_obs(object),
-  split_min_events_ = get_split_min_events(object),
-  split_min_obs_    = get_split_min_obs(object),
-  split_min_stat_   = get_split_min_stat(object),
-  cph_method_       = switch(tolower(get_cph_method(object)),
-                             'breslow' = 0,
-                             'efron'   = 1),
-  cph_eps_               = get_cph_eps(object), #
-  cph_iter_max_          = get_cph_iter_max(object),
-  cph_do_scale_          = get_cph_do_scale(object),
-  net_alpha_             = get_net_alpha(object),
-  net_df_target_         = get_net_df_target(object),
-  oobag_pred_            = get_oobag_pred(object),
-  oobag_pred_type_       = switch(get_oobag_pred_type(object),
-                                  "none" = "N",
-                                  "surv" = "S",
-                                  "risk" = "R",
-                                  "chf"  = "H"),
-  oobag_pred_horizon_    = object$pred_horizon,
-  oobag_eval_every_      = oobag_eval_every,
-  oobag_importance_      = get_importance(object) %in% c("negate", "permute"),
-  oobag_importance_type_ = switch(get_importance(object),
-                                  "none" = "O",
-                                  "anova" = "A",
-                                  "negate" = "N",
-                                  "permute" = "P"),
-  tree_seeds        = as.integer(get_tree_seeds(object)),
-  max_retry_        = get_n_retry(object),
-  f_beta            = get_f_beta(object),
-  type_beta_        = switch(get_orsf_type(object),
-                             'fast' = 'C',
-                             'cph' = 'C',
-                             'net' = 'N',
-                             'custom' = 'U'),
-  f_oobag_eval      = get_f_oobag_eval(object),
-  type_oobag_eval_  = get_type_oobag_eval(object),
-  verbose_progress  = get_verbose_progress(object)
- )
+ x_sort <- x[sorted, ]
+ y_sort <- y[sorted, ]
+ w_sort <- weights[sorted]
+
+ oobag_eval_every <- min(n_tree, get_oobag_eval_every(object))
+
+ control <- get_control(object)
+
+ orsf_out <- orsf_cpp(x = x_sort,
+                      y = y_sort,
+                      w = w_sort,
+                      tree_type_R = 3,
+                      tree_seeds = get_tree_seeds(object),
+                      loaded_forest = list(),
+                      n_tree = n_tree,
+                      mtry = get_mtry(object),
+                      sample_with_replacement = get_sample_with_replacement(object),
+                      sample_fraction = get_sample_fraction(object),
+                      vi_type_R = switch(get_importance(object),
+                                         "none" = 0,
+                                         "negate" = 1,
+                                         "permute" = 2,
+                                         "anova" = 3),
+                      vi_max_pvalue = get_vi_max_pvalue(object),
+                      oobag_R_function = get_f_oobag_eval(object),
+                      leaf_min_events = get_leaf_min_events(object),
+                      leaf_min_obs = get_leaf_min_obs(object),
+                      split_rule_R = switch(get_split_rule(object),
+                                            "logrank" = 1,
+                                            "cstat" = 2),
+                      split_min_events = get_split_min_events(object),
+                      split_min_obs = get_split_min_obs(object),
+                      split_min_stat = get_split_min_stat(object),
+                      split_max_cuts = get_n_split(object),
+                      split_max_retry = get_n_retry(object),
+
+                      lincomb_R_function = control$lincomb_R_function,
+                      lincomb_type_R = switch(control$lincomb_type,
+                                              'glm' = 1,
+                                              'random' = 2,
+                                              'net' = 3,
+                                              'custom' = 4),
+                      lincomb_eps = control$lincomb_eps,
+                      lincomb_iter_max = control$lincomb_iter_max,
+                      lincomb_scale = control$lincomb_scale,
+                      lincomb_alpha = control$lincomb_alpha,
+                      lincomb_df_target = control$lincomb_df_target,
+                      lincomb_ties_method = switch(tolower(control$lincomb_ties_method),
+                                                   'breslow' = 0,
+                                                   'efron'   = 1),
+                      pred_type_R = switch(get_oobag_pred_type(object),
+                                           "none" = 0,
+                                           "risk" = 1,
+                                           "surv" = 2,
+                                           "chf"  = 3,
+                                           "mort" = 4),
+                      pred_mode = FALSE,
+                      pred_aggregate = get_oobag_pred_type(object) != 'leaf',
+                      pred_horizon = get_oobag_pred_horizon(object),
+                      oobag = get_oobag_pred(object),
+                      oobag_eval_type_R = switch(get_type_oobag_eval(object),
+                                                 'none' = 0,
+                                                 'cstat' = 1,
+                                                 'user' = 2),
+                      oobag_eval_every = oobag_eval_every,
+                      pd_type_R = 0,
+                      pd_x_vals = list(matrix(0, ncol=1, nrow=1)),
+                      pd_x_cols = list(matrix(1L, ncol=1, nrow=1)),
+                      pd_probs = c(0),
+                      n_thread = get_n_thread(object),
+                      write_forest = TRUE,
+                      run_forest = TRUE,
+                      verbosity = get_verbose_progress(object))
 
 
- object$forest       <- orsf_out$forest
  object$pred_oobag   <- orsf_out$pred_oobag
- object$pred_horizon <- orsf_out$pred_horizon
  object$eval_oobag   <- orsf_out$eval_oobag
+ object$forest       <- orsf_out$forest
  object$importance   <- orsf_out$importance
+ object$pred_horizon <- get_oobag_pred_horizon(object)
 
  if(get_importance(object) != 'none'){
 
@@ -1099,30 +1124,33 @@ orsf_train_ <- function(object,
 
  if(get_oobag_pred(object)){
 
-  # put the oob predictions into the same order as the training data.
-  # TODO: this can be faster; see predict unsorting
-  unsorted <- vector(mode = 'integer', length = length(sorted))
-  for(i in seq_along(unsorted)) unsorted[ sorted[i] ] <- i
-
   # clear labels for oobag evaluation type
-
   object$eval_oobag$stat_type <-
-   switch(EXPR = object$eval_oobag$stat_type,
-          'H' = "Harrell's C-statistic",
-          'U' = "User-specified function")
+   switch(EXPR = as.character(object$eval_oobag$stat_type),
+          "0" = "None",
+          "1" = "Harrell's C-statistic",
+          "2" = "User-specified function")
 
+  # put the oob predictions into the same order as the training data.
+  unsorted <- collapse::radixorder(sorted)
   object$pred_oobag <- object$pred_oobag[unsorted, , drop = FALSE]
 
+  # mortality predictions should always be 1 column
+  # b/c they do not depend on the prediction horizon
+  if(get_oobag_pred_type(object) == 'mort'){
+   object$pred_oobag <-
+    object$pred_oobag[, 1L, drop = FALSE]
+
+   object$eval_oobag$stat_values <-
+    object$eval_oobag$stat_values[, 1, drop = FALSE]
+  }
+
  }
 
- attr(object, "n_leaves_mean") <-
-  mean(vapply(orsf_out$forest,
-              function(t) nrow(t$leaf_node_index),
-              FUN.VALUE = integer(1)))
+ attr(object, "n_leaves_mean") <- compute_mean_leaves(orsf_out$forest)
 
  attr(object, 'trained') <- TRUE
 
-
  object
 
 }
