@@ -28,12 +28,6 @@ get_split_min_events   <- function(object) attr(object, 'split_min_events')
 get_split_min_obs      <- function(object) attr(object, 'split_min_obs')
 get_split_min_stat     <- function(object) attr(object, 'split_min_stat')
 get_na_action          <- function(object) attr(object, 'na_action')
-get_cph_method         <- function(object) attr(object, 'cph_method')
-get_cph_eps            <- function(object) attr(object, 'cph_eps')
-get_cph_iter_max       <- function(object) attr(object, 'cph_iter_max')
-get_cph_do_scale       <- function(object) attr(object, 'cph_do_scale')
-get_net_alpha          <- function(object) attr(object, 'net_alpha')
-get_net_df_target      <- function(object) attr(object, 'net_df_target')
 get_numeric_bounds     <- function(object) attr(object, 'numeric_bounds')
 get_means              <- function(object) attr(object, 'means')
 get_modes              <- function(object) attr(object, 'modes')
@@ -49,8 +43,6 @@ get_oobag_eval_every   <- function(object) attr(object, 'oobag_eval_every')
 get_importance         <- function(object) attr(object, 'importance')
 get_importance_values  <- function(object) attr(object, 'importance_values')
 get_group_factors      <- function(object) attr(object, 'group_factors')
-get_f_beta             <- function(object) attr(object, 'f_beta')
-get_orsf_type          <- function(object) attr(object, 'orsf_type')
 get_f_oobag_eval       <- function(object) attr(object, 'f_oobag_eval')
 get_type_oobag_eval    <- function(object) attr(object, 'type_oobag_eval')
 get_tree_seeds         <- function(object) attr(object, 'tree_seeds')
