@@ -4,13 +4,6 @@
 #'
 #' Predicted risk, survival, hazard, or mortality from an ORSF model.
 #'
-#' @srrstats {G1.4} *documented with Roxygen*
-#' @srrstats {ML1.1} *using the terms 'train' and 'test'.*
-#' @srrstats {G2.0a} *specified expectations for length of `pred_horizon`. In general, inputs of length > 1 have the term 'vector' in their description, and inputs of length 1 just have the expected type.*
-#' @srrstats {G2.1a} *explicit secondary documentation of expectations on data types of all vector inputs*
- #' @srrstats {G2.8} *As part of initial pre-processing, run checks on inputs to ensure that all other sub-functions receive inputs of a single defined class or type.*
-#' @srrstats {ML1.1} *The term 'new_data' are used instead of data_test. There are two reasons for this. First, I am making an effort to be consistent with tidymodels. Second, there is a possibility that users will use predict() without the intention of testing their model, e.g., for interpretation.*
-#'
 #' @param object (*orsf_fit*) a trained oblique random survival forest
 #'   (see [orsf]).
 #'
@@ -173,6 +166,8 @@ predict.orsf_fit <- function(object,
 
  x_new <- prep_x_from_orsf(object, data = new_data[cc, ])
 
+ control <- get_control(object)
+
  orsf_out <- orsf_cpp(x = x_new,
                       y = matrix(1, ncol=2),
                       w = rep(1, nrow(x_new)),
@@ -185,7 +180,6 @@ predict.orsf_fit <- function(object,
                       sample_fraction = get_sample_fraction(object),
                       vi_type_R = 0,
                       vi_max_pvalue = get_vi_max_pvalue(object),
-                      lincomb_R_function = get_f_beta(object),
                       oobag_R_function = get_f_oobag_eval(object),
                       leaf_min_events = get_leaf_min_events(object),
                       leaf_min_obs = get_leaf_min_obs(object),
@@ -197,22 +191,20 @@ predict.orsf_fit <- function(object,
                       split_min_stat = get_split_min_stat(object),
                       split_max_cuts = get_n_split(object),
                       split_max_retry = get_n_retry(object),
-                      lincomb_type_R = switch(get_orsf_type(object),
-                                              'fast' = 1,
-                                              'cph' = 1,
+                      lincomb_R_function = control$lincomb_R_function,
+                      lincomb_type_R = switch(control$lincomb_type,
+                                              'glm' = 1,
                                               'random' = 2,
                                               'net' = 3,
                                               'custom' = 4),
-                      lincomb_eps = get_cph_eps(object),
-                      lincomb_iter_max = get_cph_iter_max(object),
-                      lincomb_scale = get_cph_do_scale(object),
-                      lincomb_alpha = get_net_alpha(object),
-                      lincomb_df_target = get_net_df_target(object),
-                      lincomb_ties_method = switch(
-                       tolower(get_cph_method(object)),
-                       'breslow' = 0,
-                       'efron'   = 1
-                      ),
+                      lincomb_eps = control$lincomb_eps,
+                      lincomb_iter_max = control$lincomb_iter_max,
+                      lincomb_scale = control$lincomb_scale,
+                      lincomb_alpha = control$lincomb_alpha,
+                      lincomb_df_target = control$lincomb_df_target,
+                      lincomb_ties_method = switch(tolower(control$lincomb_ties_method),
+                                                   'breslow' = 0,
+                                                   'efron'   = 1),
                       pred_type_R = switch(pred_type,
                                            "risk" = 1,
                                            "surv" = 2,
