@@ -297,6 +297,8 @@ orsf_vi_oobag_ <- function(object,
  # Put data in the same order that it was in when object was fit
  sorted <- order(y[, 1], -y[, 2])
 
+ control <- get_control(object)
+
  orsf_out <- orsf_cpp(x = x[sorted, , drop = FALSE],
                       y = y[sorted, , drop = FALSE],
                       w = get_weights_user(object),
@@ -311,7 +313,6 @@ orsf_vi_oobag_ <- function(object,
                                          'negate' = 1,
                                          'permute' = 2),
                       vi_max_pvalue = get_vi_max_pvalue(object),
-                      lincomb_R_function = get_f_beta(object),
                       oobag_R_function = f_oobag_eval,
                       leaf_min_events = get_leaf_min_events(object),
                       leaf_min_obs = get_leaf_min_obs(object),
@@ -323,22 +324,20 @@ orsf_vi_oobag_ <- function(object,
                       split_min_stat = get_split_min_stat(object),
                       split_max_cuts = get_n_split(object),
                       split_max_retry = get_n_retry(object),
-                      lincomb_type_R = switch(get_orsf_type(object),
-                                              'fast' = 1,
-                                              'cph' = 1,
+                      lincomb_R_function = control$lincomb_R_function,
+                      lincomb_type_R = switch(control$lincomb_type,
+                                              'glm' = 1,
                                               'random' = 2,
                                               'net' = 3,
                                               'custom' = 4),
-                      lincomb_eps = get_cph_eps(object),
-                      lincomb_iter_max = get_cph_iter_max(object),
-                      lincomb_scale = get_cph_do_scale(object),
-                      lincomb_alpha = get_net_alpha(object),
-                      lincomb_df_target = get_net_df_target(object),
-                      lincomb_ties_method = switch(
-                       tolower(get_cph_method(object)),
-                       'breslow' = 0,
-                       'efron'   = 1
-                      ),
+                      lincomb_eps = control$lincomb_eps,
+                      lincomb_iter_max = control$lincomb_iter_max,
+                      lincomb_scale = control$lincomb_scale,
+                      lincomb_alpha = control$lincomb_alpha,
+                      lincomb_df_target = control$lincomb_df_target,
+                      lincomb_ties_method = switch(tolower(control$lincomb_ties_method),
+                                                   'breslow' = 0,
+                                                   'efron'   = 1),
                       pred_type_R = 4,
                       pred_mode = FALSE,
                       pred_aggregate = TRUE,
