@@ -13,6 +13,7 @@ library(aorsf)
 set.seed(329)
 
 orsf_fit <- orsf(data = pbc_orsf, 
+                 n_tree = 5,
                  formula = Surv(time, status) ~ . - id)
 
 orsf_fit
@@ -23,7 +24,8 @@ orsf_fit
 #  
 #  orsf_fit <- pbc_orsf |>
 #   select(-id) |>
-#   orsf(formula = Surv(time, status) ~ .)
+#   orsf(formula = Surv(time, status) ~ .,
+#        n_tree = 5)
 #  
 
 ## -----------------------------------------------------------------------------
@@ -41,37 +43,10 @@ orsf_vi_permute(orsf_fit)
 orsf_vi_anova(orsf_fit)
 
 
-## -----------------------------------------------------------------------------
-
-orsf_net <- orsf(data = pbc_orsf, 
-                 formula = Surv(time, status) ~ . - id, 
-                 control = orsf_control_net(),
-                 n_tree = 50)
-
-
-## -----------------------------------------------------------------------------
-
-# tracking how long it takes to fit 50 glmnet trees
-print(
- t1 <- system.time(
-  orsf(data = pbc_orsf, 
-       formula = Surv(time, status) ~ . - id, 
-       control = orsf_control_net(),
-       n_tree = 50)
- )
-)
-
-# and how long it takes to fit 50 cph trees
-print(
- t2 <- system.time(
-  orsf(data = pbc_orsf, 
-       formula = Surv(time, status) ~ . - id, 
-       control = orsf_control_cph(),
-       n_tree = 50)
- )
-)
-
-t1['elapsed'] / t2['elapsed']
-
-
+## ----eval=FALSE---------------------------------------------------------------
+#  
+#  orsf_net <- orsf(data = pbc_orsf,
+#                   formula = Surv(time, status) ~ . - id,
+#                   control = orsf_control_net())
+#  
 
